@@ -1,8 +1,9 @@
-from rfcnt.tests import test_rfcnt
 import unittest
 from io import StringIO
 from pprint import pprint
 
+from .tests import test_rfcnt
+
 
 def run():
     stream = StringIO()
@@ -17,11 +18,3 @@ def run():
 
 if __name__ == '__main__':
     run()
-
-
-"""
-Jupyter Notebook:
-!pip install ./rfcnt-0.4.3.tar.gz
-!pip install --upgrade matplotlib
-!python -m rfcnt.run_tests
-"""
